@@ -17,22 +17,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * Author: Thomas Wood <thomas.wood@intel.com>
+ * Authors: Thomas Wood <thomas.wood@intel.com>
+ *          Rodrigo Moya <rodrigo@gnome.org>
  *
  */
 
+#include <math.h>
 #include "cc-ua-panel.h"
 
 #include <gconf/gconf-client.h>
 
 #include "gconf-property-editor.h"
 
-
-#define CONFIG_ROOT "/desktop/gnome/accessibility"
-
-#define KEY_CONFIG_ROOT CONFIG_ROOT "/keyboard"
-#define MOUSE_CONFIG_ROOT CONFIG_ROOT "/mouse"
-
 #define WID(b, w) (GtkWidget *) gtk_builder_get_object (b, w)
 
 
@@ -45,6 +41,11 @@ struct _CcUaPanelPrivate
 {
   GtkBuilder *builder;
   GConfClient *client;
+  GSettings *interface_settings;
+  GSettings *kb_settings;
+  GSettings *mouse_settings;
+  GSettings *font_settings;
+  GSettings *application_settings;
 
   GSList *notify_list;
 };
@@ -108,6 +109,36 @@ cc_ua_panel_dispose (GObject *object)
       priv->client = NULL;
     }
 
+  if (priv->interface_settings)
+    {
+      g_object_unref (priv->interface_settings);
+      priv->interface_settings = NULL;
+    }
+
+  if (priv->kb_settings)
+    {
+      g_object_unref (priv->kb_settings);
+      priv->kb_settings = NULL;
+    }
+
+  if (priv->mouse_settings)
+    {
+      g_object_unref (priv->mouse_settings);
+      priv->mouse_settings = NULL;
+    }
+
+  if (priv->font_settings)
+    {
+      g_object_unref (priv->font_settings);
+      priv->font_settings = NULL;
+    }
+
+  if (priv->application_settings)
+    {
+      g_object_unref (priv->application_settings);
+      priv->application_settings = NULL;
+    }
+
   G_OBJECT_CLASS (cc_ua_panel_parent_class)->dispose (object);
 }
 
@@ -172,16 +203,17 @@ static gchar *visual_alerts_section[] = {
 };
 
 static void
-cc_ua_panel_section_toggled (GtkToggleButton *button,
-                             GtkBuilder      *builder)
+cc_ua_panel_section_switched (GObject    *object,
+                              GParamSpec *pspec,
+                              GtkBuilder *builder)
 {
   GtkWidget *w;
   gboolean enabled;
   gchar **widgets, **s;
 
-  widgets = g_object_get_data (G_OBJECT (button), "section-widgets");
+  widgets = g_object_get_data (object, "section-widgets");
 
-  enabled = gtk_toggle_button_get_active (button);
+  enabled = gtk_switch_get_active (GTK_SWITCH (object));
 
   for (s = widgets; *s; s++)
     {
@@ -190,36 +222,37 @@ cc_ua_panel_section_toggled (GtkToggleButton *button,
     }
 }
 
-static GConfValue*
-cc_ua_panel_toggle_radios (GConfPropertyEditor *peditor,
+static void
+settings_on_off_editor_new (CcUaPanelPrivate  *priv,
+                            GSettings         *settings,
+                            const gchar       *key,
+                            GtkWidget         *widget,
+                            gchar            **section)
+{
+  /* set data to enable/disable the section this on/off switch controls */
+  if (section)
+    {
+      g_object_set_data (G_OBJECT (widget), "section-widgets", section);
+      g_signal_connect (widget, "notify::active",
+                        G_CALLBACK (cc_ua_panel_section_switched),
+                        priv->builder);
+    }
+
+  /* set up the boolean editor */
+  g_settings_bind (settings, key, widget, "active", G_SETTINGS_BIND_DEFAULT);
+}
+
+static GConfValue *
+cc_ua_panel_toggle_switch (GConfPropertyEditor *peditor,
                            const GConfValue    *value)
 {
-  GtkWidget *radio;
+  GtkWidget *sw;
   gboolean enabled;
 
   enabled = gconf_value_get_bool (value);
-  radio = (GtkWidget*) gconf_property_editor_get_ui_control (peditor);
+  sw = (GtkWidget*) gconf_property_editor_get_ui_control (peditor);
 
-
-  if (!enabled)
-    {
-      GSList *list, *l;
-
-      list = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radio));
-
-      if (list)
-        {
-          /* activate the "off" button */
-          for (l = list; l; l = l->next)
-            {
-              if (l->data == radio)
-                continue;
-
-              gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (l->data),
-                                            TRUE);
-            }
-        }
-    }
+  gtk_switch_set_active (GTK_SWITCH (sw), enabled);
 
   return gconf_value_copy (value);
 }
@@ -236,28 +269,25 @@ gconf_on_off_peditor_new (CcUaPanelPrivate  *priv,
   if (section)
     {
       g_object_set_data (G_OBJECT (widget), "section-widgets", section);
-      g_signal_connect (widget, "toggled",
-                        G_CALLBACK (cc_ua_panel_section_toggled),
+      g_signal_connect (widget, "notify::active",
+                        G_CALLBACK (cc_ua_panel_section_switched),
                         priv->builder);
     }
 
   /* set up the boolean editor */
-  peditor = gconf_peditor_new_boolean (NULL, key, widget, NULL);
-  g_object_set (peditor, "conv-to-widget-cb", cc_ua_panel_toggle_radios, NULL);
+  peditor = gconf_peditor_new_switch (NULL, key, widget, NULL);
+  g_object_set (peditor, "conv-to-widget-cb", cc_ua_panel_toggle_switch, NULL);
 
-  /* emit the notify on the key, so that the conv-to-widget-cb callback is run
-   */
+  /* emit the notify on the key, so that the conv-to-widget-cb callback is run */
   gconf_client_notify (priv->client, key);
 }
 
 /* seeing section */
-#define GTK_THEME_KEY "/desktop/gnome/interface/gtk_theme"
-#define ICON_THEME_KEY "/desktop/gnome/interface/icon_theme"
+#define GTK_THEME_KEY "gtk-theme"
+#define ICON_THEME_KEY "icon-theme"
 #define CONTRAST_MODEL_THEME_COLUMN 3
 #define DPI_MODEL_FACTOR_COLUMN 2
 
-#define DPI_KEY "/desktop/gnome/font_rendering/dpi"
-
 /* The following two functions taken from gsd-a11y-preferences-dialog.c
  *
  * Copyright (C)  2008 William Jon McCann <jmccann@redhat.com>
@@ -273,7 +303,7 @@ gconf_on_off_peditor_new (CcUaPanelPrivate  *priv,
  * DPI_HIGH_REASONABLE_VALUE], then we assume that it is lying and we use
  * DPI_FALLBACK instead.
  *
- * See get_dpi_from_gconf_or_server() below, and also
+ * See get_dpi_from_x_server() below, and also
  * https://bugzilla.novell.com/show_bug.cgi?id=217790
  */
 #define DPI_LOW_REASONABLE_VALUE 50
@@ -284,12 +314,10 @@ static gdouble
 dpi_from_pixels_and_mm (gint pixels,
                         gint mm)
 {
-  gdouble dpi;
-
   if (mm >= 1)
     return pixels / (mm / 25.4);
   else
-    return dpi = 0;
+    return 0;
 }
 
 static gdouble
@@ -327,10 +355,11 @@ get_dpi_from_x_server ()
   return dpi;
 }
 
+static void dpi_combo_box_changed (GtkComboBox *box, CcUaPanel *panel);
+
 static void
-dpi_notify_cb (GConfClient *client,
-               guint        cnxn_id,
-               GConfEntry  *entry,
+dpi_notify_cb (GSettings   *settings,
+               const gchar *key,
                CcUaPanel   *panel)
 {
   CcUaPanelPrivate *priv = panel->priv;
@@ -338,13 +367,15 @@ dpi_notify_cb (GConfClient *client,
   GtkTreeModel *model;
   GtkWidget *combo;
   gboolean valid;
-  gdouble gconf_value;
+  gdouble conf_value;
   gdouble x_dpi;
+  GtkTreeIter best;
+  gdouble distance;
 
-  if (!entry->value)
+  if (!g_str_equal (key, "dpi"))
     return;
 
-  gconf_value = gconf_value_get_float (entry->value);
+  conf_value = g_settings_get_double (settings, key);
 
   combo = WID (priv->builder, "seeing_text_size_combobox");
   model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
@@ -352,30 +383,31 @@ dpi_notify_cb (GConfClient *client,
   /* get current value from screen */
   x_dpi = get_dpi_from_x_server ();
 
-  /* see if the calculated value matches in the combobox model */
+  /* find the closest match in the combobox model */
+  distance = 1e6;
   valid = gtk_tree_model_get_iter_first (model, &iter);
   while (valid)
     {
       gfloat factor;
+      gdouble d;
 
       gtk_tree_model_get (model, &iter,
                           DPI_MODEL_FACTOR_COLUMN, &factor,
                           -1);
 
-      if (gconf_value == (float) (factor * x_dpi))
+      d = fabs (conf_value - factor * x_dpi);
+      if (d < distance)
         {
-          gtk_combo_box_set_active_iter (GTK_COMBO_BOX (combo), &iter);
-          break;
+          best = iter;
+          distance = d;
         }
 
       valid = gtk_tree_model_iter_next (model, &iter);
     }
 
-  /* if a matching value was not found in the combobox, set to "normal" */
-  if (!valid)
-    {
-      gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
-    }
+  g_signal_handlers_block_by_func (combo, dpi_combo_box_changed, panel);
+  gtk_combo_box_set_active_iter (GTK_COMBO_BOX (combo), &best);
+  g_signal_handlers_unblock_by_func (combo, dpi_combo_box_changed, panel);
 }
 
 static void
@@ -393,7 +425,7 @@ dpi_combo_box_changed (GtkComboBox *box,
                       -1);
 
   if (factor == 1.0)
-    gconf_client_unset (priv->client, DPI_KEY, NULL);
+    g_settings_reset (priv->font_settings, "dpi");
   else
     {
       gdouble x_dpi, u_dpi;
@@ -401,56 +433,58 @@ dpi_combo_box_changed (GtkComboBox *box,
       x_dpi = get_dpi_from_x_server ();
       u_dpi = (gdouble) factor * x_dpi;
 
-      gconf_client_set_float (priv->client, DPI_KEY, u_dpi, NULL);
+      g_settings_set_double (priv->font_settings, "dpi", u_dpi);
     }
 }
 
 
 static void
-contrast_notify_cb (GConfClient *client,
-                    guint        cnxn_id,
-                    GConfEntry  *entry,
-                    CcUaPanel   *panel)
+interface_settings_changed_cb (GSettings   *settings,
+                               const gchar *key,
+                               CcUaPanel   *panel)
 {
   CcUaPanelPrivate *priv = panel->priv;
-  GtkTreeIter iter;
-  GtkTreeModel *model;
-  GtkWidget *combo;
-  gboolean valid;
-  gchar *gconf_value;
 
-  gconf_value = gconf_client_get_string (client, GTK_THEME_KEY, NULL);
+  if (g_str_equal (key, "gtk-theme")) {
+    GtkTreeIter iter;
+    GtkTreeModel *model;
+    GtkWidget *combo;
+    gboolean valid;
+    gchar *theme_value;
 
-  combo = WID (priv->builder, "seeing_contrast_combobox");
-  model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
+    theme_value = g_settings_get_string (settings, GTK_THEME_KEY);
 
-  /* see if there is a matching theme name in the combobox model */
-  valid = gtk_tree_model_get_iter_first (model, &iter);
-  while (valid)
-    {
-      gchar *value;
+    combo = WID (priv->builder, "seeing_contrast_combobox");
+    model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
 
-      gtk_tree_model_get (model, &iter,
-                          CONTRAST_MODEL_THEME_COLUMN, &value,
-                          -1);
+    /* see if there is a matching theme name in the combobox model */
+    valid = gtk_tree_model_get_iter_first (model, &iter);
+    while (valid)
+      {
+        gchar *value;
 
-      if (!g_strcmp0 (value, gconf_value))
-        {
-          gtk_combo_box_set_active_iter (GTK_COMBO_BOX (combo), &iter);
-          g_free (value);
-          break;
-        }
+        gtk_tree_model_get (model, &iter,
+                            CONTRAST_MODEL_THEME_COLUMN, &value,
+                            -1);
 
-      g_free (value);
-      valid = gtk_tree_model_iter_next (model, &iter);
-    }
+        if (!g_strcmp0 (value, theme_value))
+          {
+            gtk_combo_box_set_active_iter (GTK_COMBO_BOX (combo), &iter);
+            g_free (value);
+            break;
+          }
 
-  /* if a value for the current theme was not found in the combobox, set to the
-   * "normal" option */
-  if (!valid)
-    {
-      gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 1);
-    }
+        g_free (value);
+        valid = gtk_tree_model_iter_next (model, &iter);
+      }
+
+    /* if a value for the current theme was not found in the combobox, set to the
+     * "normal" option */
+    if (!valid)
+      {
+        gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 1);
+      }
+  }
 }
 
 static void
@@ -469,13 +503,13 @@ contrast_combobox_changed_cb (GtkComboBox *box,
 
   if (g_strcmp0 (theme_name, ""))
     {
-      gconf_client_set_string (priv->client, GTK_THEME_KEY, theme_name, NULL);
-      gconf_client_set_string (priv->client, ICON_THEME_KEY, theme_name, NULL);
+      g_settings_set_string (priv->interface_settings, GTK_THEME_KEY, theme_name);
+      g_settings_set_string (priv->interface_settings, ICON_THEME_KEY, theme_name);
     }
   else
     {
-      gconf_client_unset (priv->client, GTK_THEME_KEY, NULL);
-      gconf_client_unset (priv->client, ICON_THEME_KEY, NULL);
+      g_settings_reset (priv->interface_settings, GTK_THEME_KEY);
+      g_settings_reset (priv->interface_settings, ICON_THEME_KEY);
     }
 
   g_free (theme_name);
@@ -485,36 +519,23 @@ static void
 cc_ua_panel_init_seeing (CcUaPanel *self)
 {
   CcUaPanelPrivate *priv = self->priv;
-  guint id;
 
-  gconf_client_add_dir (priv->client, "/desktop/gnome/interface",
-                        GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
-  gconf_client_add_dir (priv->client, "/desktop/gnome/font_rendering",
-                        GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
-
-  id = gconf_client_notify_add (priv->client, GTK_THEME_KEY,
-                                (GConfClientNotifyFunc) contrast_notify_cb,
-                                self, NULL, NULL);
-  priv->notify_list = g_slist_prepend (priv->notify_list, GINT_TO_POINTER (id));
-
-  id = gconf_client_notify_add (priv->client, DPI_KEY,
-                                (GConfClientNotifyFunc) dpi_notify_cb,
-                                self, NULL, NULL);
-  priv->notify_list = g_slist_prepend (priv->notify_list, GINT_TO_POINTER (id));
+  g_signal_connect (priv->font_settings, "changed", G_CALLBACK (dpi_notify_cb), self);
 
   g_signal_connect (WID (priv->builder, "seeing_contrast_combobox"), "changed",
                     G_CALLBACK (contrast_combobox_changed_cb), self);
-  gconf_client_notify (priv->client, GTK_THEME_KEY);
 
   g_signal_connect (WID (priv->builder, "seeing_text_size_combobox"), "changed",
                     G_CALLBACK (dpi_combo_box_changed), self);
-  gconf_client_notify (priv->client, DPI_KEY);
 
-  gconf_peditor_new_boolean (NULL,
-                             "/desktop/gnome/accessibility/keyboard/togglekeys_enable",
-                             WID (priv->builder,
-                                  "seeing_enable_toggle_keys_checkbutton"),
-                             NULL);
+  g_settings_bind (priv->kb_settings, "togglekeys-enable",
+                   WID (priv->builder, "seeing_enable_toggle_keys_checkbutton"), "active",
+                   G_SETTINGS_BIND_DEFAULT);
+
+  settings_on_off_editor_new (priv, priv->application_settings,
+                              "screen-magnifier-enabled",
+                              WID (priv->builder, "seeing_zoom_switch"),
+                              NULL);
 }
 
 
@@ -551,6 +572,16 @@ visual_bell_type_toggle_cb (GtkWidget *button,
     gconf_client_set_string (panel->priv->client, key, "fullscreen", NULL);
 }
 
+static void
+hearing_sound_preferences_clicked (GtkButton *button,
+                                   CcUaPanel *panel)
+{
+  CcShell *shell;
+
+  shell = cc_panel_get_shell (CC_PANEL (panel));
+  cc_shell_set_active_panel_from_id (shell, "sound", NULL);
+}
+
 static void
 cc_ua_panel_init_hearing (CcUaPanel *self)
 {
@@ -562,7 +593,7 @@ cc_ua_panel_init_hearing (CcUaPanel *self)
   gconf_client_add_dir (priv->client, "/apps/metacity/general",
                         GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 
-  w = WID (priv->builder, "hearing_visual_alerts_on_radiobutton");
+  w = WID (priv->builder, "hearing_visual_alerts_switch");
   gconf_on_off_peditor_new (priv, "/apps/metacity/general/visual_bell",
                             w, visual_alerts_section);
 
@@ -587,6 +618,9 @@ cc_ua_panel_init_hearing (CcUaPanel *self)
   g_signal_connect (WID (priv->builder, "hearing_test_flash_button"),
                     "clicked", G_CALLBACK (gdk_beep), NULL);
 
+  g_signal_connect (WID (priv->builder, "hearing_sound_preferences_button"),
+                    "clicked",
+                    G_CALLBACK (hearing_sound_preferences_clicked), self);
 }
 
 /* typing/keyboard section */
@@ -604,64 +638,51 @@ static void
 cc_ua_panel_init_keyboard (CcUaPanel *self)
 {
   CcUaPanelPrivate *priv = self->priv;
-  GConfChangeSet *changeset = NULL;
   GtkWidget *w;
 
-
   /* enable shortcuts */
   w = WID (priv->builder, "typing_keyboard_toggle_checkbox");
-  gconf_peditor_new_boolean (changeset, KEY_CONFIG_ROOT "/enable", w, NULL);
+  g_settings_bind (priv->kb_settings, "enable", w, "active", G_SETTINGS_BIND_DEFAULT);
 
   /* sticky keys */
-  w = WID (priv->builder, "typing_sticky_keys_on_radiobutton");
-  gconf_on_off_peditor_new (priv, KEY_CONFIG_ROOT "/stickykeys_enable",
-                            w, sticky_keys_section);
+  w = WID (priv->builder, "typing_sticky_keys_switch");
+  settings_on_off_editor_new (priv, priv->kb_settings, "stickykeys-enable", w, sticky_keys_section);
 
   w = WID (priv->builder, "typing_sticky_keys_disable_two_keys_checkbutton");
-  gconf_peditor_new_boolean (changeset,
-                             KEY_CONFIG_ROOT "/stickykeys_two_key_off", w,
-                             NULL);
+  g_settings_bind (priv->kb_settings, "stickykeys-two-key-off", w, "active", G_SETTINGS_BIND_DEFAULT);
 
   w = WID (priv->builder, "typing_sticky_keys_beep_modifier_checkbutton");
-  gconf_peditor_new_boolean (changeset,
-                             KEY_CONFIG_ROOT "/stickykeys_modifier_beep", w,
-                             NULL);
+  g_settings_bind (priv->kb_settings, "stickykeys-modifier-beep", w, "active", G_SETTINGS_BIND_DEFAULT);
 
   /* slow keys */
-  w = WID (priv->builder, "typing_slow_keys_on_radiobutton");
-  gconf_on_off_peditor_new (priv, KEY_CONFIG_ROOT "/slowkeys_enable",
-                            w, slow_keys_section);
+  w = WID (priv->builder, "typing_slow_keys_switch");
+  settings_on_off_editor_new (priv, priv->kb_settings, "slowkeys-enable", w, slow_keys_section);
 
   w = WID (priv->builder, "typing_slowkeys_delay_scale");
-  gconf_peditor_new_numeric_range (changeset, KEY_CONFIG_ROOT "/slowkeys_delay",
-                                   w, NULL);
+  g_settings_bind (priv->kb_settings, "slowkeys-delay",
+                   gtk_range_get_adjustment (GTK_RANGE (w)), "value",
+                   G_SETTINGS_BIND_DEFAULT);
 
   w = WID (priv->builder, "typing_slow_keys_beep_pressed_checkbutton");
-  gconf_peditor_new_boolean (changeset, KEY_CONFIG_ROOT "/slowkeys_beep_press",
-                             w, NULL);
+  g_settings_bind (priv->kb_settings, "slowkeys-beep-press", w, "active", G_SETTINGS_BIND_DEFAULT);
 
   w = WID (priv->builder, "typing_slow_keys_beep_accepted_checkbutton");
-  gconf_peditor_new_boolean (changeset, KEY_CONFIG_ROOT "/slowkeys_beep_accept",
-                             w, NULL);
+  g_settings_bind (priv->kb_settings, "slowkeys-beep-accept", w, "active", G_SETTINGS_BIND_DEFAULT);
 
   w = WID (priv->builder, "typing_slow_keys_beep_rejected_checkbutton");
-  gconf_peditor_new_boolean (changeset, KEY_CONFIG_ROOT "/slowkeys_beep_reject",
-                             w, NULL);
+  g_settings_bind (priv->kb_settings, "slowkeys-beep-reject", w, "active", G_SETTINGS_BIND_DEFAULT);
 
   /* bounce keys */
-  w = WID (priv->builder, "typing_bounce_keys_on_radiobutton");
-  gconf_on_off_peditor_new (priv, KEY_CONFIG_ROOT "/bouncekeys_enable", w,
-                            bounce_keys_section);
+  w = WID (priv->builder, "typing_bounce_keys_switch");
+  settings_on_off_editor_new (priv, priv->kb_settings, "bouncekeys-enable", w, bounce_keys_section);
 
   w = WID (priv->builder, "typing_bouncekeys_delay_scale");
-  gconf_peditor_new_numeric_range (changeset,
-                                   KEY_CONFIG_ROOT "/bouncekeys_delay", w,
-                                   NULL);
+  g_settings_bind (priv->kb_settings, "bouncekeys-delay",
+                   gtk_range_get_adjustment (GTK_RANGE (w)), "value",
+                   G_SETTINGS_BIND_DEFAULT);
 
   w = WID (priv->builder, "typing_bounce_keys_beep_rejected_checkbutton");
-  gconf_peditor_new_boolean (changeset,
-                             KEY_CONFIG_ROOT "/bouncekeys_beep_reject", w,
-                             NULL);
+  g_settings_bind (priv->kb_settings, "bouncekeys-beep-reject", w, "active", G_SETTINGS_BIND_DEFAULT);
 
   g_signal_connect (WID (priv->builder, "typing_keyboard_preferences_button"),
                     "clicked",
@@ -683,38 +704,34 @@ static void
 cc_ua_panel_init_mouse (CcUaPanel *self)
 {
   CcUaPanelPrivate *priv = self->priv;
-  GConfChangeSet *changeset = NULL;
   GtkWidget *w;
 
   /* mouse keys */
-  w = WID (priv->builder, "pointing_mouse_keys_on_radiobutton");
-  gconf_on_off_peditor_new (priv, KEY_CONFIG_ROOT "/mousekeys_enable", w, NULL);
+  w = WID (priv->builder, "pointing_mouse_keys_switch");
+  settings_on_off_editor_new (priv, priv->kb_settings, "mousekeys-enable", w, NULL);
 
   /* simulated secondary click */
-  w = WID (priv->builder, "pointing_second_click_on_radiobutton");
-  gconf_on_off_peditor_new (priv, MOUSE_CONFIG_ROOT "/delay_enable", w,
-                            secondary_click_section);
+  w = WID (priv->builder, "pointing_second_click_switch");
+  settings_on_off_editor_new (priv, priv->mouse_settings, "secondary-click-enabled", w, secondary_click_section);
 
   w = WID (priv->builder, "pointing_secondary_click_delay_scale");
-  gconf_peditor_new_numeric_range (changeset,
-                                   MOUSE_CONFIG_ROOT "/delay_time", w,
-                                   NULL);
-
+  g_settings_bind (priv->mouse_settings, "secondary-click-time",
+                   gtk_range_get_adjustment (GTK_RANGE (w)), "value",
+                   G_SETTINGS_BIND_DEFAULT);
 
   /* dwell click */
-  w = WID (priv->builder, "pointing_hover_click_on_radiobutton");
-  gconf_on_off_peditor_new (priv,MOUSE_CONFIG_ROOT "/dwell_enable", w,
-                            dwell_click_section);
+  w = WID (priv->builder, "pointing_hover_click_switch");
+  settings_on_off_editor_new (priv, priv->mouse_settings, "dwell-click-enabled", w, dwell_click_section);
 
   w = WID (priv->builder, "pointing_dwell_delay_scale");
-  gconf_peditor_new_numeric_range (changeset,
-                                   MOUSE_CONFIG_ROOT "/dwell_time", w,
-                                   NULL);
+  g_settings_bind (priv->mouse_settings, "dwell-time",
+                   gtk_range_get_adjustment (GTK_RANGE (w)), "value",
+                   G_SETTINGS_BIND_DEFAULT);
 
   w = WID (priv->builder, "pointing_dwell_threshold_scale");
-  gconf_peditor_new_numeric_range (changeset,
-                                   MOUSE_CONFIG_ROOT "/threshold", w,
-                                   NULL);
+  g_settings_bind (priv->mouse_settings, "dwell-threshold",
+                   gtk_range_get_adjustment (GTK_RANGE (w)), "value",
+                   G_SETTINGS_BIND_DEFAULT);
 
   /* mouse preferences button */
   g_signal_connect (WID (priv->builder, "pointing_mouse_preferences_button"),
@@ -736,14 +753,14 @@ cc_ua_panel_init (CcUaPanel *self)
                        "pointing_sizegroup", "pointing_sizegroup2",
                        "pointing_scale_sizegroup", "sizegroup1",
                        "hearing_sizegroup",
-                       "NULL" };
+                       NULL };
 
   priv = self->priv = UA_PANEL_PRIVATE (self);
 
   priv->builder = gtk_builder_new ();
 
   gtk_builder_add_objects_from_file (priv->builder,
-                                     GNOMECC_DATA_DIR "/ui/uap.ui",
+                                     GNOMECC_UI_DIR "/uap.ui",
                                      objects,
                                      &err);
 
@@ -760,8 +777,14 @@ cc_ua_panel_init (CcUaPanel *self)
 
   priv->client = gconf_client_get_default ();
 
-  gconf_client_add_dir (priv->client, CONFIG_ROOT,
-                        GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+  priv->interface_settings = g_settings_new ("org.gnome.desktop.interface");
+  g_signal_connect (priv->interface_settings, "changed",
+                    G_CALLBACK (interface_settings_changed_cb), self);
+
+  priv->kb_settings = g_settings_new ("org.gnome.desktop.a11y.keyboard");
+  priv->mouse_settings = g_settings_new ("org.gnome.desktop.a11y.mouse");
+  priv->font_settings = g_settings_new ("org.gnome.settings-daemon.plugins.xsettings");
+  priv->application_settings = g_settings_new ("org.gnome.desktop.a11y.applications");
 
   cc_ua_panel_init_keyboard (self);
   cc_ua_panel_init_mouse (self);
